@@ -12,10 +12,10 @@ module Roo
       def extract_comments
         return {} unless doc_exists?
 
-        Hash[doc.xpath('//comments/commentList/comment').map do |comment|
+        doc.xpath('//comments/commentList/comment').each_with_object({}) do |comment, hash|
           value = (comment.at_xpath('./text/r/t') || comment.at_xpath('./text/t')).text
-          [::Roo::Utils.ref_to_key(comment.attributes['ref'].to_s), value]
-        end]
+          hash[::Roo::Utils.ref_to_key(comment['ref'].to_s)] = value
+        end
       end
     end
   end
